@@ -1,4 +1,4 @@
-# Copyright 1998-2003, Paul Johnson (pjcj@cpan.org)
+# Copyright 1998-2004, Paul Johnson (pjcj@cpan.org)
 
 # This software is free.  It is licensed under the same terms as Perl itself.
 
@@ -26,7 +26,7 @@ my %Top_tag_order;
 
 BEGIN
 {
-  $VERSION = "1.13";
+  $VERSION = "1.14";
 
   $Tags =
   {
@@ -175,7 +175,6 @@ BEGIN
 
   while (my ($tag, $name) = each (%$Tags))
   {
-    # print "looking at tag $tag <$name>\n";
     $Funcs{$tag} = $Funcs{lc $tag} = $tag;
     if ($name)
     {
@@ -232,15 +231,16 @@ sub AUTOLOAD
   goto &$func
 }
 
-use Gedcom::Grammar    1.13;
-use Gedcom::Individual 1.13;
-use Gedcom::Family     1.13;
-use Gedcom::Event      1.13;
+use Gedcom::Grammar    1.14;
+use Gedcom::Individual 1.14;
+use Gedcom::Family     1.14;
+use Gedcom::Event      1.14;
 
 sub new
 {
   my $proto = shift;
   my $class = ref($proto) || $proto;
+  @_ = (gedcom_file => @_) if @_ == 1;
   my $self =
   {
     records   => [],
@@ -334,12 +334,12 @@ sub new
           $l2->add("ADDR", "http://www.pjcj.net");
           $l2 = $l1->add("DATA");
             $l3 = $l2->add("COPR",
-                           'Copyright 1998-2003, Paul Johnson (pjcj@cpan.org)');
+                           'Copyright 1998-2004, Paul Johnson (pjcj@cpan.org)');
         $l1 = $l0->add("NOTE", "");
       for (split /\n/, <<'EOH')
 This output was generated by Gedcom.pm.
-Gedcom.pm is Copyright 1999-2003, Paul Johnson (pjcj@cpan.org)
-Version 1.13 - 6th December 2003
+Gedcom.pm is Copyright 1999-2004, Paul Johnson (pjcj@cpan.org)
+Version 1.14 - 5th April 2004
 
 Gedcom.pm is free.  It is licensed under the same terms as Perl itself.
 
@@ -392,8 +392,8 @@ sub write_xml
 <!--
 
 This output was generated by Gedcom.pm.
-Gedcom.pm is Copyright 1999-2003, Paul Johnson (pjcj@cpan.org)
-Version 1.13 - 6th December 2003
+Gedcom.pm is Copyright 1999-2004, Paul Johnson (pjcj@cpan.org)
+Version 1.14 - 5th April 2004
 
 Gedcom.pm is free.  It is licensed under the same terms as Perl itself.
 
@@ -492,8 +492,6 @@ sub renumber
 
 sub sort_sub
 {
-  my $self = shift;
-
   # subroutine to sort on tag order first, and then on xref
 
   my $t = sub
@@ -638,7 +636,6 @@ sub next_xref
   my $last = 0;
   for my $c (@{$self->{record}->_items})
   {
-    # warn "last $last xref $c->{xref}\n";
     $last = $1 if defined $c->{xref} and $c->{xref} =~ /$re/ and $1 > $last;
   }
   $type . ++$last
@@ -652,14 +649,14 @@ __END__
 
 Gedcom - a module to manipulate Gedcom genealogy files
 
-Version 1.13 - 6th December 2003
+Version 1.14 - 5th April 2004
 
 =head1 SYNOPSIS
 
   use Gedcom;
 
   my $ged = Gedcom->new;
-  my $ged = Gedcom->new(gedcom_file => $gedcom_file);
+  my $ged = Gedcom->new($gedcom_file);
   my $ged = Gedcom->new(grammar_version => 5.5,
                         gedcom_file     => $gedcom_file,
                         read_only       => 1,
@@ -692,7 +689,7 @@ Version 1.13 - 6th December 2003
 
 =head1 DESCRIPTION
 
-Copyright 1998-2003, Paul Johnson (pjcj@cpan.org)
+Copyright 1998-2004, Paul Johnson (pjcj@cpan.org)
 
 This software is free.  It is licensed under the same terms as Perl itself.
 
@@ -781,7 +778,7 @@ most simple test is I<birthdates.t>.
 The first thing to do is to read in the Gedcom file.  At its most
 simple, this will involve a statement such as
 
-  my $ged = Gedcom->new(gedcom_file => $gedcom_file);
+  my $ged = Gedcom->new($gedcom_file);
 
 It is now possible to access the records within the gedcom file.  Each
 individual and family is a record.  Records can contain other records.
@@ -801,9 +798,9 @@ To access information about the individual, use a function of the same
 name as the Gedcom tag, or its description.  Tags and descriptions are
 listed at the head of Gedcom.pm.  For example
 
-    for my $b ($i->birth)
-    {
-    }
+  for my $b ($i->birth)
+  {
+  }
 
 will loop through all the birth records in the individual.  Usually
 there will only be one such record, but there may be zero, one or more.
@@ -872,6 +869,25 @@ It is possible to get all the individuals in the gedcom file as
 
   my @individuals = $ged->individuals;
 
+So putting everything together, here is a little program which will
+print out the names and birthdates of everyone in a GEDCOM file
+specified on the command line.
+
+  #!/bin/perl -w
+
+  use strict;
+  use Gedcom;
+
+  my $ged = Gedcom->new(shift);
+
+  for my $i ($ged->individuals)
+  {
+      for my $bd ($i->get_value("birth date"))
+      {
+          print $i->name, " was born on $bd\n";
+      }
+  }
+
 =head1 HASH MEMBERS
 
 I have not gone the whole hog with data encapsulation and such within
@@ -910,7 +926,7 @@ See Gedcom::Record.pm for more details.
 
   my $ged = Gedcom->new;
 
-  my $ged = Gedcom->new(gedcom_file => $gedcom_file);
+  my $ged = Gedcom->new($gedcom_file);
 
   my $ged = Gedcom->new(grammar_version => 5.5,
                         gedcom_file     => $gedcom_file,
